@@ -6,20 +6,17 @@
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
 
-use serde::Deserialize;
 use std::collections::HashMap;
 
-use crate::{sink::Sink, source::Source};
+use crate::{read_filter::ReadFilterKind, sink::Sink, source::Source};
 
-#[derive(Deserialize)]
-#[serde(transparent, deny_unknown_fields)]
-pub struct Tasks(pub HashMap<String, Task>);
+pub type Tasks = HashMap<String, Task>;
 
-#[derive(Deserialize, Debug)]
-#[serde(deny_unknown_fields)]
+#[derive(Debug)]
 pub struct Task {
 	pub disabled: Option<bool>,
+	pub refresh: u64,
+	pub read_filter_kind: ReadFilterKind,
 	pub sink: Sink,
 	pub source: Source,
-	pub refresh: u64,
 }
